%define major   5
%define minor   4
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

Name:           assimp
Version:        5.4.3
Release:        %mkrel 2
Summary:        Library to import various 3D model formats into applications
Group:          Graphics/3D
# Assimp is BSD
# Bundled contrib/clipper is Boost
# Bundled contrib/Open3DGC is MIT
# Bundled contrib/openddlparser is MIT
# Bundled contrib/stb_image is MIT
# Bundled contrib/unzip is zlib
# Bundled contrib/zip is unlicense
# Bundled contrib/zlib is zlib
License:        BSD and MIT and Boost and unlicense and zlib
URL:            https://github.com/assimp/assimp

# Github releases include nonfree models, source tarball must be re-generated
# using assimp_generate_tarball.sh
Source0:        %{name}-%{version}-free.tar.xz
Source1:        assimp_generate_tarball.sh

# Un-bundle libraries that are provided by the distribution.
# Also fixes FTBFS: https://github.com/assimp/assimp/issues/4334
Patch0:         assimp-5.4.3-mga-unbundle.patch

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  cmake(RapidJSON)
BuildRequires:  cmake(utf8cpp)
BuildRequires:  pkgconfig(draco)
BuildRequires:  pkgconfig(gtest)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(poly2tri)
BuildRequires:  pkgconfig(pugixml)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(stb)
BuildRequires:  pkgconfig(polyclipping)

#Provides: bundled(polyclipping) = 6.4.2
Provides: bundled(open3dgc)
Provides: bundled(openddl-parser)
# https://github.com/kuba--/zip
Provides: bundled(zip)

%description
Assimp, the Open Asset Import Library, is a free library to import various
well-known 3D model formats into applications. Assimp aims to provide a full
asset conversion pipeline for use in game engines and real-time rendering
systems, but is not limited to these applications.

This package contains the assimp binary, a tool to work with various formats.

%files
%doc Readme.md CREDITS CHANGES
%{_bindir}/%{name}

#----------------------------------------------------------------------------

%package -n     %{libname}
Summary:        Library to import various 3D model formats into applications
Group:          System/Libraries

%description -n %{libname}
Assimp, the Open Asset Import Library, is a free library to import various
well-known 3D model formats into applications. Assimp aims to provide a full
asset conversion pipeline for use in game engines and real-time rendering
systems, but is not limited to these applications.

%files -n       %{libname}
%doc Readme.md CREDITS CHANGES
%license LICENSE
%{_libdir}/lib%{name}.so.%{major}
%{_libdir}/lib%{name}.so.%{version}

#----------------------------------------------------------------------------

%package -n     %{devname}
Summary:        Header files and development libraries for assimp
Group:          Development/C++
Provides:       %{name}-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Requires:       pkgconfig(stb)

%description -n %{devname}
This package contains the header files and development libraries for assimp.
You need to install it if you want to develop programs using assimp.

%files -n       %{devname}
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/cmake/%{name}-%{major}.%{minor}/
%{_libdir}/pkgconfig/%{name}.pc

#----------------------------------------------------------------------------

%prep
%autosetup -p1

# Get rid of bundled libs so we can't accidentally build against them
rm -rf contrib/android-cmake
rm -rf contrib/clipper
rm -rf contrib/draco
rm -rf contrib/gtest
rm -rf contrib/poly2tri
rm -rf contrib/pugixml
rm -rf contrib/rapidjson
rm -rf contrib/stb
rm -rf contrib/unzip
rm -rf contrib/utf8cpp
#rm -rf contrib/zip
rm -rf contrib/zlib

%build
%cmake \
  -DASSIMP_BUILD_TESTS=OFF \
  -DASSIMP_BUILD_ZLIB=OFF \
  -DASSIMP_WARNINGS_AS_ERRORS=OFF \
  -DASSIMP_BUILD_ASSIMP_TOOLS=ON \
  -DCLIPPER_INCLUDE_PATH=%{_includedir}/polyclipping

%cmake_build

%install
%cmake_install

# HACK hackaround missing imported target "draco::draco"
# The link interface of target "assimp::assimp" contains:
#     draco::draco
# but the target was not found.  Possible reasons include:
#     * There is a typo in the target name.
#     * A find_package call is missing for an IMPORTED target.
#     * An ALIAS target is missing.
sed -i 's|draco::draco;|draco;|' %{buildroot}%{_libdir}/cmake/assimp-%{major}.%{minor}/assimpTargets.cmake


%changelog
* Sun Jun 29 2025 umeabot <umeabot> 5.4.3-2.mga10
+ Revision: 2227660
- Mageia 10 Mass Rebuild

* Sat Sep 14 2024 daviddavid <daviddavid> 5.4.3-1.mga10
+ Revision: 2096189
- new version: 5.4.3

* Fri Aug 16 2024 daviddavid <daviddavid> 5.4.2-1.mga10
+ Revision: 2086739
- new version: 5.4.2
- use system rapidjson and polyclipping

* Mon Mar 04 2024 daviddavid <daviddavid> 5.3.1-4.mga10
+ Revision: 2047555
- rebuild for new draco 1.5.7

* Fri Feb 16 2024 daviddavid <daviddavid> 5.3.1-3.mga10
+ Revision: 2041962
- devel sub-pkg requires pkgconfig(stb)

* Fri Feb 16 2024 daviddavid <daviddavid> 5.3.1-2.mga10
+ Revision: 2041955
- hackaround missing imported target "draco::draco" (don't find a better fix for now)

* Wed Dec 06 2023 daviddavid <daviddavid> 5.3.1-1.mga10
+ Revision: 2013775
- new version: 5.3.1
- switch to stb instead of old stbi development package

* Sun Oct 15 2023 wally <wally> 5.2.2-5.mga10
+ Revision: 1997037
- rebuild for minizip from minizip-ng

* Sat May 21 2022 wally <wally> 5.2.2-4.mga9
+ Revision: 1859676
- rebuild for poly2tri 20220520 snapshot

* Fri Mar 18 2022 papoteur <papoteur> 5.2.2-3.mga9
+ Revision: 1797994
- Reinstate a deprecated gltfpbr macro

* Fri Mar 18 2022 papoteur <papoteur> 5.2.2-2.mga9
+ Revision: 1797967
- Disable -Werror flag

* Sat Feb 26 2022 akien <akien> 5.2.2-1.mga9
+ Revision: 1785378
- Version 5.2.2

* Sun Jan 02 2022 akien <akien> 5.1.5-1.mga9
+ Revision: 1766233
- Version 5.1.5

* Tue Nov 16 2021 akien <akien> 5.1.0-1.mga9
+ Revision: 1757420
- Version 5.1.0
- Partial sync with Fedora, but custom patch for super hacky unbundling

* Sat Feb 15 2020 umeabot <umeabot> 3.3.1-5.mga8
+ Revision: 1526508
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Mon Jun 03 2019 akien <akien> 3.3.1-4.mga7
+ Revision: 1399526
- Drop doc package, does not build and not really useful

* Fri Sep 21 2018 umeabot <umeabot> 3.3.1-3.mga7
+ Revision: 1294997
- Mageia 7 Mass Rebuild

* Fri Aug 11 2017 daviddavid <daviddavid> 3.3.1-2.mga7
+ Revision: 1139804
- backport some patches from fedora (this should fix qt3d build against assimp system)
- add a doc subpackage

* Sat Oct 29 2016 akien <akien> 3.3.1-1.mga6
+ Revision: 1063933
- Version 3.3.1

* Mon Jul 11 2016 akien <akien> 3.2-3.mga6
+ Revision: 1041066
- Fix debug postfix in cmake config files

* Sun Apr 24 2016 akien <akien> 3.2-2.mga6
+ Revision: 1005874
- Build against new poly2tri

* Wed Jan 13 2016 akien <akien> 3.2-1.mga6
+ Revision: 922902
- Version 3.2

* Wed Oct 15 2014 umeabot <umeabot> 3.1.1-3.mga5
+ Revision: 746314
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.1.1-2.mga5
+ Revision: 678000
- Mageia 5 Mass Rebuild

* Mon Jun 23 2014 akien <akien> 3.1.1-1.mga5
+ Revision: 638765
- Version 3.1.1

* Wed Jun 11 2014 akien <akien> 3.1-2.mga5
+ Revision: 635664
- Revert enabling the build with system-wide polyclipping, our version is too recent
- Use system-wide polyclipping instead of embedded clipper.hpp

* Mon Jun 09 2014 akien <akien> 3.1-1.mga5
+ Revision: 635262
- Use newly packaged system-wide poly2tri
- Version 3.1

* Thu Jun 05 2014 akien <akien> 3.0.1270-1.mga5
+ Revision: 633526
- Generate HTML documentation (patch)
- Use system minizip (patch)
- import source RPM from OpenMandriva

